@@ -1,4 +1,4 @@
-use crate::db::Database;
+use crate::{config::Config, db::Database};
 use eyre::WrapErr;
 use structopt::StructOpt;
 
@@ -7,9 +7,9 @@ use std::path::PathBuf;
 /// Init and/or update the cyndikator database
 #[derive(StructOpt)]
 pub struct Init {
-    /// where the database is located
-    #[structopt(short, long, env = "CYNDIKATOR_DATABASE")]
-    database: Option<String>,
+    /// Config to load
+    #[structopt(short, long, env = "CYNDIKATOR_CONFIG")]
+    config: Option<PathBuf>,
 
     /// Update the database schema
     #[structopt(short, long)]
@@ -18,10 +18,8 @@ pub struct Init {
 
 impl Init {
     pub async fn run(self) -> eyre::Result<()> {
-        let path = self
-            .database
-            .map_or_else(Database::default_path, PathBuf::from);
-        let mut db = Database::create(path)?;
+        let config = Config::load(self.config.as_deref())?;
+        let mut db = Database::create(config.database_path()?)?;
 
         if self.update {
             db.migrate().wrap_err("unable to migrate")?;
